@@ -47,7 +47,7 @@ private Q_SLOTS:
         QCOMPARE(vac.totalDoses(), 2);
         QCOMPARE(vac.date(), QDate(2021, 5, 29));
         QCOMPARE(vac.vaccineType(), QLatin1String("SARS-CoV-2 mRNA vaccine"));
-        QCOMPARE(vac.vaccine(), QLatin1String("Spikevax (previously COVID-19 Vaccine Moderna)"));
+        QCOMPARE(vac.vaccine(), QLatin1String("Spikevax"));
         QCOMPARE(vac.vaccineUrl().toString(), QLatin1String("https://ec.europa.eu/health/documents/community-register/html/h1507.htm"));
         QCOMPARE(vac.manufacturer(), QLatin1String("Moderna Biotech Spain S.L."));
         QCOMPARE(vac.certificateIssuer(), QLatin1String("Robert Koch-Institut"));
@@ -71,7 +71,7 @@ private Q_SLOTS:
         QCOMPARE(vac.totalDoses(), 2);
         QCOMPARE(vac.date(), QDate(2021, 5, 29));
         QCOMPARE(vac.vaccineType(), QLatin1String("SARS-CoV-2 mRNA vaccine"));
-        QCOMPARE(vac.vaccine(), QLatin1String("Spikevax (previously COVID-19 Vaccine Moderna)"));
+        QCOMPARE(vac.vaccine(), QLatin1String("Spikevax"));
         QCOMPARE(vac.manufacturer(), QLatin1String("Moderna Biotech Spain S.L."));
         QCOMPARE(vac.certificateIssuer(), QLatin1String("Robert Koch-Institut"));
         QCOMPARE(vac.certificateId(), QLatin1String("URN:UVCI:01DE/IZ12345A/5CWLU12RNOB9RXSEOP6FG8#W"));
